==> entityengine-1.2.2-sources.jar: org/ofbiz/core/entity/transaction/TransactionFactoryInterface.java <==
/*
 * $Id: TransactionFactoryInterface.java,v 1.1 2005/04/01 05:58:03 sfarquhar Exp $
 *
 *  Copyright (c) 2001 The Open For Business Project - www.ofbiz.org
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a
 *  copy of this software and associated documentation files (the "Software"),
 *  to deal in the Software without restriction, including without limitation
 *  the rights to use, copy, modify, merge, publish, distribute, sublicense,
 *  and/or sell copies of the Software, and to permit persons to whom the
 *  Software is furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 *  MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 *  IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 *  CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT
 *  OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR
 *  THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package org.ofbiz.core.entity.transaction;


import javax.transaction.*;
import java.sql.*;
import org.w3c.dom.Element;

import org.ofbiz.core.entity.*;

/**
 * TyrexTransactionFactory - central source for Tyrex JTA objects
 *
 *@author     <a href="mailto:jonesde@ofbiz.org">David E. Jones</a>
 *@version    1.0
 *@created    July 1, 2001, 5:03 PM
 */
public interface TransactionFactoryInterface {

    public TransactionManager getTransactionManager();

    public UserTransaction getUserTransaction();
    
    public String getTxMgrName();
    
    public Connection getConnection(String helperName) throws SQLException, GenericEntityException;

    /**
     * Removes a datasource, and if necessary, shuts it down
     *
     * @param helperName The name of the datasource to remove
     */
    public void removeDatasource(String helperName);
}

==> entityengine-3.0.9-sources.jar: org/ofbiz/core/entity/transaction/TransactionFactoryInterface.java <==
/*
 * $Id: TransactionFactoryInterface.java,v 1.1 2005/04/01 05:58:03 sfarquhar Exp $
 *
 *  Copyright (c) 2001 The Open For Business Project - www.ofbiz.org
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a
 *  copy of this software and associated documentation files (the "Software"),
 *  to deal in the Software without restriction, including without limitation
 *  the rights to use, copy, modify, merge, publish, distribute, sublicense,
 *  and/or sell copies of the Software, and to permit persons to whom the
 *  Software is furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included
 *  in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 *  MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 *  IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
 *  CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT
 *  OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR
 *  THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package org.ofbiz.core.entity.transaction;


import org.ofbiz.core.entity.GenericEntityException;

import javax.transaction.TransactionManager;
import javax.transaction.UserTransaction;
import java.sql.Connection;
import java.sql.SQLException;

/**
 * TyrexTransactionFactory - central source for Tyrex JTA objects
 *
 * @author <a href="mailto:jonesde@ofbiz.org">David E. Jones</a>
 * @version 1.0
 * @created July 1, 2001, 5:03 PM
 */
public interface TransactionFactoryInterface {

    public TransactionManager getTransactionManager();

    public UserTransaction getUserTransaction();

    public String getTxMgrName();

    public Connection getConnection(String helperName) throws SQLException, GenericEntityException;

    /**
     * Removes a datasource, and if necessary, shuts it down
     *
     * @param helperName The name of the datasource to remove
     */
    public void removeDatasource(String helperName);
}
